@@ -15,6 +15,7 @@
 #include "actiongroup.h"
 #include "appinfo.h"
 #include "application.h"
+#include "applicationcommandline.h"
 #include "asyncinitable.h"
 #include "asyncresult.h"
 #include "bufferedinputstream.h"
@@ -23,6 +24,7 @@
 #include "credentials.h"
 #include "datainputstream.h"
 #include "dataoutputstream.h"
+#include "dbusaddress.h"
 #include "dbusauthobserver.h"
 #include "dbusconnection.h"
 #include "dbuserror.h"
@@ -104,6 +106,7 @@ extern "C"
 
 GType g_app_launch_context_get_type(void);
 GType g_application_get_type(void);
+GType g_application_command_line_get_type(void);
 GType g_buffered_input_stream_get_type(void);
 GType g_buffered_output_stream_get_type(void);
 GType g_cancellable_get_type(void);
@@ -181,6 +184,7 @@ GQuark g_resolver_error_quark(void);
 
 namespace Gio {  class AppLaunchContext_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Application_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class ApplicationCommandLine_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class BufferedInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class BufferedOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Cancellable_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -258,6 +262,7 @@ void wrap_init()
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(g_app_launch_context_get_type(), &Gio::AppLaunchContext_Class::wrap_new);
   Glib::wrap_register(g_application_get_type(), &Gio::Application_Class::wrap_new);
+  Glib::wrap_register(g_application_command_line_get_type(), &Gio::ApplicationCommandLine_Class::wrap_new);
   Glib::wrap_register(g_buffered_input_stream_get_type(), &Gio::BufferedInputStream_Class::wrap_new);
   Glib::wrap_register(g_buffered_output_stream_get_type(), &Gio::BufferedOutputStream_Class::wrap_new);
   Glib::wrap_register(g_cancellable_get_type(), &Gio::Cancellable_Class::wrap_new);
@@ -327,6 +332,7 @@ void wrap_init()
   // Register the gtkmm gtypes:
   Gio::AppLaunchContext::get_type();
   Gio::Application::get_type();
+  Gio::ApplicationCommandLine::get_type();
   Gio::BufferedInputStream::get_type();
   Gio::BufferedOutputStream::get_type();
   Gio::Cancellable::get_type();
