@@ -2,29 +2,29 @@
 #ifndef _GLIBMM_TIMEVAL_H
 #define _GLIBMM_TIMEVAL_H
 
-/* $Id: timeval.h 270 2006-04-14 10:13:46Z  $ */
+/* $Id$ */
 
 /* timeval.h
  *
  * Copyright (C) 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib/gtypes.h>
-#include <glib/gtimer.h>
+#include <glib.h>
+#include <glibmm/ustring.h>
 
 namespace Glib
 {
@@ -47,6 +47,15 @@ struct TimeVal : public GTimeVal
    * works also on Win32. 
    */
   void assign_current_time();
+  
+  /** Converts a string containing an ISO 8601 encoded date and time
+   * to a Glib::TimeVal and puts it in TimeVal instance.
+   * @param iso_date ISO 8601 encoded string.
+   * @return <tt>true</tt> if conversion was successful.
+   *
+   * @newin{2,22}
+   */
+  bool assign_from_iso8601(const Glib::ustring& iso_date);
 
   void add(const TimeVal& rhs);
   void subtract(const TimeVal& rhs);
@@ -69,6 +78,13 @@ struct TimeVal : public GTimeVal
    */
   inline double as_double() const;
 
+  /** Returns an ISO 8601 encoded string, relative to the Coordinated
+   * Universal Time (UTC).
+   *
+   * @newin{2,22}
+   */
+  Glib::ustring as_iso8601() const;
+
   inline bool negative() const;
 
   /** Checks whether the stored time interval is positive.
@@ -141,7 +157,7 @@ TimeVal& TimeVal::operator-=(long seconds)
 inline
 double TimeVal::as_double() const
 {
-  return tv_sec + ((double) tv_usec / (double) G_USEC_PER_SEC);
+  return double(tv_sec) + double(tv_usec) / double(G_USEC_PER_SEC);
 }
 
 inline
